@@ -1,4 +1,4 @@
-package Pcore::WebDriver v0.9.1;
+package Pcore::WebDriver v0.9.2;
 
 use Pcore -dist, -const, -class, -result,
   -export => {
@@ -212,7 +212,7 @@ around new => sub ( $orig, $self, $driver, @args ) {
         host         => $args{host},
         port         => $args{port},
         is_chrome    => $driver eq 'chrome' ? 1 : 0,
-        is_phantomjs => $driver eq 'phantomejs' ? 1 : 0,
+        is_phantomjs => $driver eq 'phantomjs' ? 1 : 0,
       },
       __PACKAGE__;
 
@@ -240,7 +240,12 @@ around new => sub ( $orig, $self, $driver, @args ) {
 sub _get_chrome_cmd ( $self, $args ) {
     $args->{bin} = $ENV->share->get( $MSWIN ? '/bin/webdriver/chromedriver.exe' : '/bin/webdriver/chromedriver-linux-x64' ) if !$args->{bin};
 
-    my $cmd = [ $args->{bin}, "--port=$args->{port}", '--silent', defined $args->{args} ? $args->{args}->@* : () ];
+    my $cmd = [    #
+        $args->{bin},
+        "--port=$args->{port}",
+        '--silent',
+        defined $args->{args} ? $args->{args}->@* : (),
+    ];
 
     return $cmd;
 }
@@ -248,7 +253,15 @@ sub _get_chrome_cmd ( $self, $args ) {
 sub _get_phantomjs_cmd ( $self, $args ) {
     $args->{bin} = $ENV->share->get( $MSWIN ? '/bin/webdriver/phantomjs.exe' : '/bin/webdriver/phantomjs-linux-x64/bin/phantomjs' );
 
-    my $cmd = [ $args->{bin}, "--webdriver=$args->{host}:$args->{port}", '--webdriver-loglevel=NONE', defined $args->{args} ? $args->{args}->@* : () ];
+    my $cmd = [    #
+        $args->{bin},
+        "--webdriver=$args->{host}:$args->{port}",
+        '--webdriver-loglevel=NONE',
+        '--debug=no',
+        '--ignore-ssl-errors=yes',
+        '--web-security=no',
+        defined $args->{args} ? $args->{args}->@* : (),
+    ];
 
     return $cmd;
 }
@@ -272,7 +285,7 @@ sub new_session ( $self, @args ) {
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
 ## |    3 |                      | Subroutines::ProhibitUnusedPrivateSubroutines                                                                  |
 ## |      | 240                  | * Private subroutine/method '_get_chrome_cmd' declared but not used                                            |
-## |      | 248                  | * Private subroutine/method '_get_phantomjs_cmd' declared but not used                                         |
+## |      | 253                  | * Private subroutine/method '_get_phantomjs_cmd' declared but not used                                         |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
