@@ -16,6 +16,8 @@ has id => ( is => 'ro', isa => Str, init_arg => undef );
 has _cmd_queue  => ( is => 'ro', isa => ArrayRef, init_arg => undef );
 has _is_waiting => ( is => 'ro', isa => Bool,     init_arg => undef );
 
+const our $DEFAULT_USERAGENT => 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/60.0.3112.101 Safari/537.36';
+
 # https://github.com/SeleniumHQ/selenium/wiki/JsonWireProtocol
 our $CMD;
 const $CMD => {
@@ -333,32 +335,33 @@ sub _get_desired_caps ( $self, $args ) {
     my $caps = {
 
         # javascriptEnabled => $self->{disable_javascript} ? \0 : \1,
-        acceptSslCerts  => \1,
-        takesScreenshot => \1,
-        handlesAlerts   => \1,
-        proxy           => {
-            proxyType => 'direct',
-
-            # httpProxy     => $self->http_proxy,
-            # sslProxy      => $self->ssl_proxy,
-            # socksProxy    => $self->socks_proxy,
-            # socksUsername => $self->socks_proxy_username,
-            # socksPassword => $self->socks_proxy_password,
-        },
+        # acceptSslCerts  => \1,
+        # takesScreenshot => \1,
+        # handlesAlerts   => \1,
     };
 
+    my $useragent = !exists $args->{useragent} ? $DEFAULT_USERAGENT : $args->{useragent};
+
     # chrome options
     if ( $self->{wdh}->{is_chrome} ) {
-        my @headless = $args->{headless} || !$MSWIN ? ( '--headless', '--disable-gpu' ) : ();
-
-        my $ua = 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/60.0.3112.101 Safari/537.36';
-
         $caps->{chromeOptions} = {
+            args => [    #
 
-            # '--headless', '--disable-gpu',
-            # "user-data-dir=$ENV->{TEMP_DIR}"
-            # 'no-sandbox',
-            args => [ 'start-maximized', 'disable-infobars', '--disable-popup-blocking', '--disable-default-apps', '--disable-web-security', "user-data-dir=$ENV->{TEMP_DIR}chrome-wds-" . P->uuid->str, @headless, ( $args->{args} ? $args->{args}->@* : () ), '--no-sandbox', "--user-agent=$ua" ],
+                # https://bugs.chromium.org/p/chromium/issues/detail?id=721739
+                # headless chrome not ignoring self-signed certs
+                $args->{proxy} ? ( "--proxy-server=$args->{proxy}", '--ignore-certificate-errors' ) : (),
+
+                '--start-maximized',
+                '--disable-infobars',
+                '--disable-popup-blocking',
+                '--disable-default-apps',
+                '--disable-web-security',
+                "--user-data-dir=$ENV->{TEMP_DIR}chrome-wds-" . P->uuid->str,
+                '--no-sandbox',    # required for run under docker
+                defined $useragent ? "--user-agent=$useragent" : (),
+                $args->{headless} || !$MSWIN ? ( '--headless', '--disable-gpu' ) : (),
+                $args->{args} ? $args->{args}->@* : (),
+            ],
             binary => $args->{bin} // q[],
 
             #     prefs => {
@@ -372,7 +375,15 @@ sub _get_desired_caps ( $self, $args ) {
 
     # phantomjs options
     elsif ( $self->{wdh}->{is_phantomjs} ) {
-        $caps->{'phantomjs.page.settings.userAgent'} = $args->{useragent} if $args->{useragent};
+        if ( $args->{proxy} ) {
+            $caps->{proxy} = {
+                proxyType => 'manual',
+                httpProxy => $args->{proxy},
+                sslProxy  => $args->{proxy},
+            };
+        }
+
+        $caps->{'phantomjs.page.settings.userAgent'} = $useragent if defined $useragent;
     }
 
     return { desiredCapabilities => $caps };
@@ -388,13 +399,13 @@ around new => sub ( $orig, $self, @args ) {
         body      => to_json( $self->_get_desired_caps( {@args} ) ),
         on_finish => sub ($res) {
             if ( !$res ) {
-                $cb->( result(500), undef );
+                $cb->( undef, result 500 );
             }
             else {
                 my $data = from_json $res->body;
 
                 if ( $data->{status} ) {
-                    $cb->( result( [ 500, $data->{value}->{message} ] ), undef );
+                    $cb->( undef, result [ 500, $data->{value}->{message} ] );
                 }
                 else {
                     my $wds = bless {
@@ -406,7 +417,7 @@ around new => sub ( $orig, $self, @args ) {
                       },
                       __PACKAGE__;
 
-                    $cb->( result(200), $wds );
+                    $cb->( $wds, result 200 );
                 }
             }
 
@@ -507,7 +518,7 @@ sub _send_cmd ( $self ) {
 ## |======+======================+================================================================================================================|
 ## |    3 | 1                    | Modules::ProhibitExcessMainComplexity - Main code has high complexity score (22)                               |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    2 | 352                  | CodeLayout::ProhibitQuotedWordLists - List of quoted literal words                                             |
+## |    2 | 362                  | CodeLayout::ProhibitQuotedWordLists - List of quoted literal words                                             |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
